<?php
/**
 * Triggers
 *
 * @package GamiPress\Contact_Form_7\Triggers
 * @since 1.0.0
 */

// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Register Contact Form 7 specific triggers
 *
 * @param array $triggers
 * @return mixed
 */
function gamipress_wpcf7_activity_triggers( $triggers ) {

    $triggers[__( 'Contact Form 7', 'gamipress-contact-form-7-integration' )] = array(
        'gamipress_wpcf7_new_form_submission' => __( 'Successful submit a form', 'gamipress-contact-form-7-integration' ),
        'gamipress_wpcf7_specific_new_form_submission' => __( 'Successful submit a specific form', 'gamipress-contact-form-7-integration' ),
    );

    return $triggers;

}
add_filter( 'gamipress_activity_triggers', 'gamipress_wpcf7_activity_triggers' );

/**
 * Register Contact Form 7 specific activity triggers
 *
 * @since  1.0.0
 *
 * @param  array $specific_activity_triggers
 * @return array
 */
function gamipress_wpcf7_specific_activity_triggers( $specific_activity_triggers ) {

    $specific_activity_triggers['gamipress_wpcf7_specific_new_form_submission'] = array( 'wpcf7_contact_form' );

    return $specific_activity_triggers;
}
add_filter( 'gamipress_specific_activity_triggers', 'gamipress_wpcf7_specific_activity_triggers' );

/**
 * Register Contact Form 7 specific activity triggers labels
 *
 * @since  1.0.0
 *
 * @param  array $specific_activity_trigger_labels
 * @return array
 */
function gamipress_wpcf7_specific_activity_trigger_label( $specific_activity_trigger_labels ) {

    $specific_activity_trigger_labels['gamipress_wpcf7_specific_new_form_submission'] = __( 'Submit %s', 'gamipress-contact-form-7-integration' );

    return $specific_activity_trigger_labels;
}
add_filter( 'gamipress_specific_activity_trigger_label', 'gamipress_wpcf7_specific_activity_trigger_label' );

/**
 * Get user for a given trigger action.
 *
 * @since  1.0.0
 *
 * @param  integer $user_id user ID to override.
 * @param  string  $trigger Trigger name.
 * @param  array   $args    Passed trigger args.
 * @return integer          User ID.
 */
function gamipress_wpcf7_trigger_get_user_id( $user_id, $trigger, $args ) {

    switch ( $trigger ) {
        case 'gamipress_wpcf7_new_form_submission':
        case 'gamipress_wpcf7_specific_new_form_submission':
            $user_id = $args[1];
            break;
    }

    return $user_id;

}

add_filter( 'gamipress_trigger_get_user_id', 'gamipress_wpcf7_trigger_get_user_id', 10, 3);

/**
 * Get the id for a given specific trigger action.
 *
 * @since  1.0.0
 *
 * @param  integer  $specific_id Specific ID.
 * @param  string  $trigger Trigger name.
 * @param  array   $args    Passed trigger args.
 *
 * @return integer          Specific ID.
 */
function gamipress_wpcf7_specific_trigger_get_id( $specific_id, $trigger = '', $args = array() ) {

    switch ( $trigger ) {
        case 'gamipress_wpcf7_specific_new_form_submission':
            $specific_id = $args[0];
            break;
    }

    return $specific_id;
}
add_filter( 'gamipress_specific_trigger_get_id', 'gamipress_wpcf7_specific_trigger_get_id', 10, 3 );

/**
 * Extended meta data for event trigger logging
 *
 * @since 1.0.1
 *
 * @param array 	$log_meta
 * @param integer 	$user_id
 * @param string 	$trigger
 * @param integer 	$site_id
 * @param array 	$args
 *
 * @return array
 */
function gamipress_wpcf7_log_event_trigger_meta_data( $log_meta, $user_id, $trigger, $site_id, $args ) {

    switch ( $trigger ) {
        case 'gamipress_wpcf7_new_form_submission':
        case 'gamipress_wpcf7_specific_new_form_submission':
            // Add the form ID
            $log_meta['form_id'] = $args[0];
            break;
    }

    return $log_meta;
}
add_filter( 'gamipress_log_event_trigger_meta_data', 'gamipress_wpcf7_log_event_trigger_meta_data', 10, 5 );